pub struct Comments {
pub pre_lines: Vec<String>,
pub post_comment: Option<String>,
}Fields
pre_lines: Vec<String>Lines of comments or blank lines that precede the main text line.
post_comment: Option<String>Comment at the end of the main text line.
Implementations
Sourceimpl Comments
impl Comments
pub fn new() -> Self
pub fn display_pre_comments(&self) -> DisplayPreComments<'_>
pub fn display_post_comment(&self) -> DisplayPostComment<'_>
pub fn remove_leading_blank_lines(&mut self)