pub struct SymLabel {
pub external: bool,
pub mode: InstructionMode,
}Fields
external: boolIf true, the label is not used by the function itself, but accessed externally. Such labels are only discovered during relocation analysis, which is not performed by the dis/delink subcommands. External label symbols are therefore included in symbols.txt, hence this boolean.
mode: InstructionModeTrait Implementations
impl Copy for SymLabel
impl Eq for SymLabel
impl StructuralPartialEq for SymLabel