pub struct SymFunction {
pub mode: InstructionMode,
pub size: u32,
pub unknown: bool,
}Fields
mode: InstructionModesize: u32unknown: boolIs true for functions that were not found during function analysis, but are being called from somewhere. This can
happen if the function is encrypted.