pub struct Symbol {
pub name: String,
pub kind: SymbolKind,
pub addr: u32,
pub ambiguous: bool,
pub local: bool,
}Fields
name: Stringkind: SymbolKindaddr: u32ambiguous: boolIf true, this symbol is involved in an ambiguous external reference to one of many overlays
local: boolIf true, this symbol is local to its translation unit and will not cause duplicate symbol definitions in the linker
Implementations
Sourceimpl Symbol
impl Symbol
pub fn from_function(function: &Function) -> Self
pub fn new_unknown_function(name: String, addr: u32, thumb: bool) -> Self
pub fn new_label(name: String, addr: u32, thumb: bool) -> Self
pub fn new_external_label(name: String, addr: u32, thumb: bool) -> Self
pub fn new_pool_constant(name: String, addr: u32) -> Self
pub fn new_jump_table(name: String, addr: u32, size: u32, code: bool) -> Self
pub fn new_data( name: String, addr: u32, data: SymData, ambiguous: bool, ) -> Symbol
pub fn new_bss(name: String, addr: u32, data: SymBss, ambiguous: bool) -> Symbol
pub fn size(&self, max_address: u32) -> u32